@@ -137,7 +137,7 @@ class VocabularyProvider:
         concepts.
 
         .. deprecated:: 0.2.0
-            This method has been deprectad, please use :meth:`expand`.
+            This method has been deprecated, please use :meth:`expand`.
 
         :param id: A concept id.
         :rtype: A list of id's or `False` if the concept doesn't exist.
@@ -172,7 +172,7 @@ class VocabularyProvider:
 
 class MemoryProvider(VocabularyProvider):
     '''
-    An provider that keeps everything in memory.
+    A provider that keeps everything in memory.
 
     The data is passed in the constructor of this provider as a list of
     :class:`skosprovider.skos.Concept` and :class:`skosprovider.skos.Collection`
@@ -184,7 +184,7 @@ class MemoryProvider(VocabularyProvider):
     Is searching for labels case insensitive?
 
     By default a search for a label is done case insensitive. Older versions of 
-    this provider were case sensitive. If this behaviour is decided, this can 
+    this provider were case sensitive. If this behaviour is desired, this can 
     be triggered by providing a `case_insensitive` keyword to the constructor.
     '''
 
@@ -293,18 +293,18 @@ class DictionaryProvider(MemoryProvider):
     def _from_dict(self, data):
         if 'type' in data and data['type'] == 'collection':
             return Collection(
-                data['id'],
-                data['labels'] if 'labels' in data else [],
-                data['members'] if 'members' in data else []
+                id=data['id'],
+                labels=data['labels'] if 'labels' in data else [],
+                members=data['members'] if 'members' in data else []
             )
         else:
             return Concept(
-                data['id'],
-                data['labels'] if 'labels' in data else [],
-                data['notes'] if 'notes' in data else [],
-                data['broader'] if 'broader' in data else [],
-                data['narrower'] if 'narrower' in data else [],
-                data['related'] if 'related' in data else [],
+                id=data['id'],
+                labels=data['labels'] if 'labels' in data else [],
+                notes=data['notes'] if 'notes' in data else [],
+                broader=data['broader'] if 'broader' in data else [],
+                narrower=data['narrower'] if 'narrower' in data else [],
+                related=data['related'] if 'related' in data else [],
             )
 
 
